@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: profunctors
 version: 5.2
-id: profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
-key: profu_2wAzSKoUTy2128FFgbcrKX
+id: profunctors-5.2-026a1eb9905bccdb097d36481584da83
+key: profu_C46VciwewvULi7qxLnZUmt
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,14 +27,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
-hs-libraries: HSprofunctors-5.2-2wAzSKoUTy2128FFgbcrKX
+hs-libraries: HSprofunctors-5.2-C46VciwewvULi7qxLnZUmt
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
-    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
-    comonad-5-e98e7adc8875accf64a86529d9aeae51
+    base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
+    bifunctors-5.3-b6e9a28a0175204e65003b150c0bbe80
+    comonad-5-3b2e208311908bc5a9db1ceb26126917
     contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
-    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
+    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
